@@ -1,5 +1,5 @@
 # This represents a fairly significant load time for shells. A clever way of caching would be ideal
-if [[ -z KSLURM_COMPUTE_NODES ]]; then
+if [[ -z $KSLURM_COMPUTE_NODES ]]; then
   export KSLURM_COMPUTE_NODES=$(sinfo -N -h | awk '{print $1'} | sort -u)
 fi
 
@@ -12,7 +12,6 @@ pip () {
       cmd="$cmd --no-index"
     fi
     if [[ -n $installtype ]]; then
-      echo "updated"
       if command -v kslurm &> /dev/null; then
         pipdir=$(kslurm config pipdir)
         if [[ -z $pipdir ]]; then
@@ -22,7 +21,7 @@ pip () {
           if [[ ! -d "$wheelhouse" ]]; then
             mkdir -p "$wheelhouse"
           fi
-          cmd="$cmd --find-links='$wheelhouse'"
+          cmd="$cmd --find-links=$wheelhouse"
           export PIP_WHEEL_DIR=$wheelhouse
         fi
       else
